Transcript
Claims
{% for speaker in speakers %}
{% endfor %}

{% for utterance in transcript.utterances %}
- {{ utterance.speaker }}
  {{ utterance.text }}
  ({{ format_timestamp(utterance.start_time) }})
{% endfor %}

Transcript
Claims
{% for speaker in speakers %}
{% endfor %}

{% for utterance in claims.utterances %} {% for claim in utterance.claims %}
- {{ utterance.speaker }}
  {{ claim.text }}
  ({{ format_timestamp(utterance.start_time) }})
{% endfor %} {% endfor %}

×

## Assign Speakers

×

## Help

Help text here